@@ -1,5 +1,8 @@
-/*  libtifiles - TI File Format library
- *  Copyright (C) 2002-2003  Romain Lievin
+/* Hey EMACS -*- linux-c -*- */
+/* $Id: types92p.h 3056 2006-11-06 17:12:50Z roms $ */
+
+/*  libtifiles - file format library, a part of the TiLP project
+ *  Copyright (C) 1999-2005  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,7 +22,7 @@
 #ifndef __TIFILES_DEFS92P__
 #define __TIFILES_DEFS92P__
 
-#include "stdints.h"
+#include "stdints2.h"
 
 #define TI92p_MAXTYPES 48
 
@@ -42,7 +45,8 @@
 #define TI92p_BKUP 0x1D
 #define TI92p_FDIR 0x1F
 #define TI92p_DIR  TI92p_FDIR
-#define TI92p_ASM  0x21
+#define TI92p_GETCERT 0x20
+#define TI92p_ASM	  0x21
 #define TI92p_IDLIST  0x22
 #define TI92p_AMS     0x23
 #define TI92p_APPL    0x24
